import os
import socket
import urllib

class Response:

    def __init__(self,s):
        res = ''
        while True:
            buff = s.recv(1024)
            if not buff:
                break
            res += buff
        self.resp_line,self.headers,self.body = self.parse_response(res)

    def parse_response(self,resp):
        lines = resp.split('\n')
        resp_line = lines[0].rstrip()
        if len(lines)==1:
            return resp_line,None,None
        headers = []
        for i,line in enumerate(lines[1:]):
            if line.strip():
                headers.append(line.rstrip())
            else:
                break
        body = '\n'.join(lines[i+2:])
        return resp_line,headers,body

s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
s.connect(('localhost',80))
s.close()

s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
s.connect(('localhost',80))

s.send('GET /index.html HTTP/1.1\r\n')
s.send('\r\n')
res = Response(s) 

print res.body == file(os.path.normpath('../webapps/index.html'),'rb').read()

s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
s.connect(('localhost',80))
s.send('PUT /index.html HTTP/1.1\r\n')
s.send('\r\n')
res = Response(s) 
print res.resp_line

res = urllib.urlopen('http://localhost/index.html')
print len(res.read())

body = urllib.urlencode({'spam':'lqhglg'})
res = urllib.urlopen('http://localhost/demo/myScript.py',body)
print res.info()
